==> libreoffice-still-sdk-24.8.7-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "XContainer", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
    [ "XNameContainer", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a8b2267babadb7074470bbe24aa2cc000", null ],
    [ "XMultiServiceFactory", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a12bb2ce3c118a1ba6fe14b9ba279ad2a", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Closeable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a09d866ede19f359434dc5ea312802a59", null ],
    [ "DesktopAsParent", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#acb5533fcefe96a188a33eba49634d803", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HScroll", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a07d61e5d645f9566018c59fa3164052f", null ],
    [ "ImageURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ae0d5ed0dbfdb5c4cbc19502b1814844e", null ],
    [ "Moveable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a037c145113cd95829afe9a107377f609", null ],
    [ "ScrollHeight", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#adb6ef40c9a460592dbe2a10d671c6513", null ],
    [ "ScrollLeft", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a5a6a7e3e393d2c40effdf4606cf49da7", null ],
    [ "ScrollTop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a03b5a2fe61f9d75df5949cdb7bfd1d9b", null ],
    [ "ScrollWidth", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ad4331e9870a36ec6b3233c893ea498c1", null ],
    [ "Sizeable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ad71e4713c39536def72b80cccb885eb9", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "Title", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#aa7b633091e7820b835d04d0d5fc197c7", null ],
    [ "VScroll", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#aa4476f2609beb00283e82a3b77c22202", null ]
];

==> libreoffice-still-sdk-25.2.7-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "com::sun::star::container::XContainer", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ],
    [ "com::sun::star::container::XNameContainer", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a8b2267babadb7074470bbe24aa2cc000", null ],
    [ "com::sun::star::lang::XMultiServiceFactory", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a12bb2ce3c118a1ba6fe14b9ba279ad2a", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Closeable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a09d866ede19f359434dc5ea312802a59", null ],
    [ "DesktopAsParent", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#acb5533fcefe96a188a33eba49634d803", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "HScroll", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a07d61e5d645f9566018c59fa3164052f", null ],
    [ "ImageURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ae0d5ed0dbfdb5c4cbc19502b1814844e", null ],
    [ "Moveable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a037c145113cd95829afe9a107377f609", null ],
    [ "ScrollHeight", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#adb6ef40c9a460592dbe2a10d671c6513", null ],
    [ "ScrollLeft", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a5a6a7e3e393d2c40effdf4606cf49da7", null ],
    [ "ScrollTop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a03b5a2fe61f9d75df5949cdb7bfd1d9b", null ],
    [ "ScrollWidth", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ad4331e9870a36ec6b3233c893ea498c1", null ],
    [ "Sizeable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#ad71e4713c39536def72b80cccb885eb9", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "Title", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#aa7b633091e7820b835d04d0d5fc197c7", null ],
    [ "VScroll", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlDialogModel.html#aa4476f2609beb00283e82a3b77c22202", null ]
];
